@@ -30,7 +30,11 @@ from gettext import gettext as _
 #gettext.textdomain('indicator-cpufreq')
 
 def readable_frequency(f):
-    return _("%s GHz") % locale.format(_("%.2f"), f / 1.0e6)
+    # temp hack for properly displaying intel turbo mode (actual freq + 1000kHz)
+    label = _("%s GHz") % locale.format(_("%.2f"), f / 1.0e6)
+    if f % 10000 != 0:
+        label = label + " " + _("(turbo mode)")
+    return label
 
 governor_names = {
     'conservative': _("Conservative"),
